needs colorize.fs

\ inspired by colorize.fs and see.fs

<A Cyan bold >BG A>      Use# CT!

: my.string ( c-addr u n -- )
    attr @ >r

    dup cells ct + @ attr!
    (.string)
    
    r> attr!
; latestxt is .string

<a a> attr!