\ COMMENT $XConsortium: clB8x8.bdf,v 1.2 94/04/11 12:07:01 gildea Exp $
\ COMMENT
\ COMMENT  Copyright 1989 Dale Schumacher, dal@syntel.mn.org
\ COMMENT                 399 Beacon Ave.
\ COMMENT                 St. Paul, MN  55104-3527
\ COMMENT
\ COMMENT  Permission to use, copy, modify, and distribute this software and
\ COMMENT  its documentation for any purpose and without fee is hereby
\ COMMENT  granted, provided that the above copyright notice appear in all
\ COMMENT  copies and that both that copyright notice and this permission
\ COMMENT  notice appear in supporting documentation, and that the name of
\ COMMENT  Dale Schumacher not be used in advertising or publicity pertaining to
\ COMMENT  distribution of the software without specific, written prior
\ COMMENT  permission.  Dale Schumacher makes no representations about the
\ COMMENT  suitability of this software for any purpose.  It is provided "as
\ COMMENT  is" without express or implied warranty.
\ COMMENT
\ FONT -Schumacher-Clean-Bold-R-Normal--8-80-75-75-C-80-ISO646.1991-IRVSIZE 8 75 75
\ FONTNAME_REGISTRY ""
\ FOUNDRY "Schumacher"
\ FAMILY_NAME "Clean"
\ WEIGHT_NAME "Bold"
\ SLANT "R"
\ SETWIDTH_NAME "Normal"
\ ADD_STYLE_NAME ""
\ PIXEL_SIZE 8
\ POINT_SIZE 80
\ RESOLUTION_X 75
\ RESOLUTION_Y 75
\ SPACING "C"
\ AVERAGE_WIDTH 80
\ FONT_ASCENT 7
\ FONT_DESCENT 1
\ DEFAULT_CHAR 0
\ COPYRIGHT "Copyright 1989 Dale Schumacher."
: clb8x8-char-32 ( x y -- w ) \  
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-33 ( x y -- w ) \ !
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▗▖ " 1+
2drop 4 ;
: clb8x8-char-34 ( x y -- w ) \ "
2dup at-xy ."  ▐▐ " 1+
2dup at-xy ."  ▝▝ " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-35 ( x y -- w ) \ #
2dup at-xy ."  ▖▗ " 1+
2dup at-xy ." ▝▛▜▘" 1+
2dup at-xy ." ▗▙▟▖" 1+
2dup at-xy ."  ▘▝ " 1+
2drop 4 ;
: clb8x8-char-36 ( x y -- w ) \ $
2dup at-xy ."  ▗▙▖" 1+
2dup at-xy ."  ▚▙ " 1+
2dup at-xy ."  ▄▙▘" 1+
2dup at-xy ."   ▘ " 1+
2drop 4 ;
: clb8x8-char-37 ( x y -- w ) \ %
2dup at-xy ." ▗▚ ▖" 1+
2dup at-xy ."  ▘▞ " 1+
2dup at-xy ."  ▞▗▚" 1+
2dup at-xy ."    ▘" 1+
2drop 4 ;
: clb8x8-char-38 ( x y -- w ) \ &
2dup at-xy ." ▗▀▘ " 1+
2dup at-xy ."  ▙  " 1+
2dup at-xy ." ▐ ▚▘" 1+
2dup at-xy ."  ▀▘▘" 1+
2drop 4 ;
: clb8x8-char-39 ( x y -- w ) \ '
2dup at-xy ."   ▛ " 1+
2dup at-xy ."  ▝  " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-40 ( x y -- w ) \ (
2dup at-xy ."  ▗▛ " 1+
2dup at-xy ."  █  " 1+
2dup at-xy ."  ▜▖ " 1+
2dup at-xy ."   ▀ " 1+
2drop 4 ;
: clb8x8-char-41 ( x y -- w ) \ )
2dup at-xy ."  ▝▙ " 1+
2dup at-xy ."   ▐▌" 1+
2dup at-xy ."   ▟▘" 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-42 ( x y -- w ) \ *
2dup at-xy ."   ▌ " 1+
2dup at-xy ." ▝▚▙▀" 1+
2dup at-xy ."  ▗▚ " 1+
2dup at-xy ."  ▘ ▘" 1+
2drop 4 ;
: clb8x8-char-43 ( x y -- w ) \ +
2dup at-xy ."   ▌ " 1+
2dup at-xy ." ▗▄▙▄" 1+
2dup at-xy ."   ▌ " 1+
2dup at-xy ."   ▘ " 1+
2drop 4 ;
: clb8x8-char-44 ( x y -- w ) \ ,
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▞  " 1+
2drop 4 ;
: clb8x8-char-45 ( x y -- w ) \ -
2dup at-xy ."     " 1+
2dup at-xy ." ▗▄▄▄" 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-46 ( x y -- w ) \ .
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-47 ( x y -- w ) \ /
2dup at-xy ."   ▐ " 1+
2dup at-xy ."   ▌ " 1+
2dup at-xy ."  ▐  " 1+
2dup at-xy ."  ▌  " 1+
2drop 4 ;
: clb8x8-char-48 ( x y -- w ) \ 0
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-49 ( x y -- w ) \ 1
2dup at-xy ."  ▗█ " 1+
2dup at-xy ."   █ " 1+
2dup at-xy ."   █ " 1+
2dup at-xy ."   ▀ " 1+
2drop 4 ;
: clb8x8-char-50 ( x y -- w ) \ 2
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ."   ▟▘" 1+
2dup at-xy ."  ▟▘ " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-51 ( x y -- w ) \ 3
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ."  ▗▟▘" 1+
2dup at-xy ." ▗▖▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-52 ( x y -- w ) \ 4
2dup at-xy ."  ▗█ " 1+
2dup at-xy ." ▗▛█ " 1+
2dup at-xy ." ▝▀█▘" 1+
2dup at-xy ."  ▝▀▘" 1+
2drop 4 ;
: clb8x8-char-53 ( x y -- w ) \ 5
2dup at-xy ." ▐▛▀▘" 1+
2dup at-xy ." ▝▀▜▖" 1+
2dup at-xy ." ▗▖▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-54 ( x y -- w ) \ 6
2dup at-xy ."  ▟▀ " 1+
2dup at-xy ." ▐▙▄ " 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-55 ( x y -- w ) \ 7
2dup at-xy ." ▐▛▜▌" 1+
2dup at-xy ."   ▟▘" 1+
2dup at-xy ."  ▗▛ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-56 ( x y -- w ) \ 8
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ." ▝▙▟▘" 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-57 ( x y -- w ) \ 9
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ." ▝▙▟▌" 1+
2dup at-xy ."   ▟▘" 1+
2dup at-xy ."  ▀▘ " 1+
2drop 4 ;
: clb8x8-char-58 ( x y -- w ) \ :
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▝▘ " 1+
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-59 ( x y -- w ) \ ;
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▝▘ " 1+
2dup at-xy ."  ▗▖ " 1+
2dup at-xy ."  ▞  " 1+
2drop 4 ;
: clb8x8-char-60 ( x y -- w ) \ <
2dup at-xy ."   ▗▄" 1+
2dup at-xy ." ▗▟▀ " 1+
2dup at-xy ."  ▝▜▄" 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-61 ( x y -- w ) \ =
2dup at-xy ."     " 1+
2dup at-xy ." ▝▀▀▀" 1+
2dup at-xy ." ▗▄▄▄" 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-62 ( x y -- w ) \ >
2dup at-xy ." ▗▄  " 1+
2dup at-xy ."  ▝▜▄" 1+
2dup at-xy ." ▗▟▀ " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-63 ( x y -- w ) \ ?
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ."   ▟▘" 1+
2dup at-xy ."  ▝▘ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-64 ( x y -- w ) \ @
2dup at-xy ." ▗▀▀▚" 1+
2dup at-xy ." ▐▐▜▐" 1+
2dup at-xy ." ▐▝▀▘" 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-65 ( x y -- w ) \ A
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  █▜ " 1+
2dup at-xy ." ▐▛▀▌" 1+
2dup at-xy ." ▀▘ ▀" 1+
2drop 4 ;
: clb8x8-char-66 ( x y -- w ) \ B
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▙▄▛" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-67 ( x y -- w ) \ C
2dup at-xy ."  ▟▀▙" 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▙ ▄" 1+
2dup at-xy ."  ▝▀▘" 1+
2drop 4 ;
: clb8x8-char-68 ( x y -- w ) \ D
2dup at-xy ." ▐▛▜▖" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▌▗▛" 1+
2dup at-xy ." ▝▀▀ " 1+
2drop 4 ;
: clb8x8-char-69 ( x y -- w ) \ E
2dup at-xy ." ▐▛▀▀" 1+
2dup at-xy ." ▐▙▄ " 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▀▀▀" 1+
2drop 4 ;
: clb8x8-char-70 ( x y -- w ) \ F
2dup at-xy ." ▐▛▀▀" 1+
2dup at-xy ." ▐▙▄ " 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▘  " 1+
2drop 4 ;
: clb8x8-char-71 ( x y -- w ) \ G
2dup at-xy ."  ▟▀▙" 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▙▝█" 1+
2dup at-xy ."  ▝▀▀" 1+
2drop 4 ;
: clb8x8-char-72 ( x y -- w ) \ H
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▙▄█" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-73 ( x y -- w ) \ I
2dup at-xy ." ▝▜▛▘" 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-74 ( x y -- w ) \ J
2dup at-xy ."  ▝▜▌" 1+
2dup at-xy ."   ▐▌" 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-75 ( x y -- w ) \ K
2dup at-xy ." ▐▌▗▛" 1+
2dup at-xy ." ▐▙▛ " 1+
2dup at-xy ." ▐▌▜▖" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-76 ( x y -- w ) \ L
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-77 ( x y -- w ) \ M
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▛▞█" 1+
2dup at-xy ." ▐▌▘█" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-78 ( x y -- w ) \ N
2dup at-xy ." ▐▙ █" 1+
2dup at-xy ." ▐▛▖█" 1+
2dup at-xy ." ▐▌▚█" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-79 ( x y -- w ) \ O
2dup at-xy ."  ▟▜▖" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▙▗▛" 1+
2dup at-xy ."  ▝▀ " 1+
2drop 4 ;
: clb8x8-char-80 ( x y -- w ) \ P
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▙▄▛" 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▘  " 1+
2drop 4 ;
: clb8x8-char-81 ( x y -- w ) \ Q
2dup at-xy ."  ▟▜▖" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▙▗▛" 1+
2dup at-xy ."  ▝▜▖" 1+
2drop 4 ;
: clb8x8-char-82 ( x y -- w ) \ R
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▙▄▛" 1+
2dup at-xy ." ▐▌▜▖" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-83 ( x y -- w ) \ S
2dup at-xy ." ▗▛▀▙" 1+
2dup at-xy ." ▝▙▄▖" 1+
2dup at-xy ." ▗▖ █" 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-84 ( x y -- w ) \ T
2dup at-xy ." ▝▜▛▘" 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-85 ( x y -- w ) \ U
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-86 ( x y -- w ) \ V
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▙▗▛" 1+
2dup at-xy ."  ▜▟▘" 1+
2dup at-xy ."  ▝▀ " 1+
2drop 4 ;
: clb8x8-char-87 ( x y -- w ) \ W
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▌▌█" 1+
2dup at-xy ." ▐▙▚█" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-88 ( x y -- w ) \ X
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▜▛ " 1+
2dup at-xy ." ▗▛▜▖" 1+
2dup at-xy ." ▝▘▝▘" 1+
2drop 4 ;
: clb8x8-char-89 ( x y -- w ) \ Y
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ."  ▜▛ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▝▘ " 1+
2drop 4 ;
: clb8x8-char-90 ( x y -- w ) \ Z
2dup at-xy ." ▝▀▜▌" 1+
2dup at-xy ."  ▗▛ " 1+
2dup at-xy ." ▗▛  " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-91 ( x y -- w ) \ [
2dup at-xy ."  ▐▛▘" 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▝▀▘" 1+
2drop 4 ;
: clb8x8-char-92 ( x y -- w ) \ \
2dup at-xy ."  ▌  " 1+
2dup at-xy ."  ▐  " 1+
2dup at-xy ."   ▌ " 1+
2dup at-xy ."   ▐ " 1+
2drop 4 ;
: clb8x8-char-93 ( x y -- w ) \ ]
2dup at-xy ."  ▀█ " 1+
2dup at-xy ."   █ " 1+
2dup at-xy ."   █ " 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-94 ( x y -- w ) \ ^
2dup at-xy ."  ▟▚ " 1+
2dup at-xy ." ▝▘ ▘" 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-95 ( x y -- w ) \ _
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2dup at-xy ." ▝▀▀▀" 1+
2drop 4 ;
: clb8x8-char-96 ( x y -- w ) \ `
2dup at-xy ."  ▝▌ " 1+
2dup at-xy ."   ▝ " 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-97 ( x y -- w ) \ a
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀█" 1+
2dup at-xy ." ▐▌▗█" 1+
2dup at-xy ."  ▀▘▀" 1+
2drop 4 ;
: clb8x8-char-98 ( x y -- w ) \ b
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-99 ( x y -- w ) \ c
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀▘" 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-100 ( x y -- w ) \ d
2dup at-xy ."    █" 1+
2dup at-xy ." ▗▛▀█" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ."  ▀▀▀" 1+
2drop 4 ;
: clb8x8-char-101 ( x y -- w ) \ e
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀▙" 1+
2dup at-xy ." ▐▛▀▀" 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-102 ( x y -- w ) \ f
2dup at-xy ."  ▟▀▘" 1+
2dup at-xy ." ▝█▀ " 1+
2dup at-xy ."  █  " 1+
2dup at-xy ."  ▀  " 1+
2drop 4 ;
: clb8x8-char-103 ( x y -- w ) \ g
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀█" 1+
2dup at-xy ." ▝▙▄█" 1+
2dup at-xy ."  ▄▄▛" 1+
2drop 4 ;
: clb8x8-char-104 ( x y -- w ) \ h
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-105 ( x y -- w ) \ i
2dup at-xy ."  ▝▘ " 1+
2dup at-xy ." ▝▜▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-106 ( x y -- w ) \ j
2dup at-xy ."   ▝▘" 1+
2dup at-xy ."  ▝▜▌" 1+
2dup at-xy ."   ▐▌" 1+
2dup at-xy ."  ▄▟▘" 1+
2drop 4 ;
: clb8x8-char-107 ( x y -- w ) \ k
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▐▌▟▘" 1+
2dup at-xy ." ▐▛▙ " 1+
2dup at-xy ." ▝▘▝▘" 1+
2drop 4 ;
: clb8x8-char-108 ( x y -- w ) \ l
2dup at-xy ."  ▜▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."  ▀▀ " 1+
2drop 4 ;
: clb8x8-char-109 ( x y -- w ) \ m
2dup at-xy ."     " 1+
2dup at-xy ." ▐▛▞▙" 1+
2dup at-xy ." ▐▌▌█" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-110 ( x y -- w ) \ n
2dup at-xy ."     " 1+
2dup at-xy ." ▐▙▀▙" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▝▘ ▀" 1+
2drop 4 ;
: clb8x8-char-111 ( x y -- w ) \ o
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀▙" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ."  ▀▀▘" 1+
2drop 4 ;
: clb8x8-char-112 ( x y -- w ) \ p
2dup at-xy ."     " 1+
2dup at-xy ." ▐▛▀▙" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▛▀▘" 1+
2drop 4 ;
: clb8x8-char-113 ( x y -- w ) \ q
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀█" 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ."  ▀▀█" 1+
2drop 4 ;
: clb8x8-char-114 ( x y -- w ) \ r
2dup at-xy ."     " 1+
2dup at-xy ." ▐▙▀▘" 1+
2dup at-xy ." ▐▌  " 1+
2dup at-xy ." ▝▘  " 1+
2drop 4 ;
: clb8x8-char-115 ( x y -- w ) \ s
2dup at-xy ."     " 1+
2dup at-xy ." ▗▛▀▘" 1+
2dup at-xy ."  ▀▜▖" 1+
2dup at-xy ." ▝▀▀ " 1+
2drop 4 ;
: clb8x8-char-116 ( x y -- w ) \ t
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ." ▝▜▛▘" 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."   ▀▘" 1+
2drop 4 ;
: clb8x8-char-117 ( x y -- w ) \ u
2dup at-xy ."     " 1+
2dup at-xy ." ▐▌ █" 1+
2dup at-xy ." ▐▌▗█" 1+
2dup at-xy ."  ▀▘▀" 1+
2drop 4 ;
: clb8x8-char-118 ( x y -- w ) \ v
2dup at-xy ."     " 1+
2dup at-xy ." ▝█▐▛" 1+
2dup at-xy ."  ▜▟▘" 1+
2dup at-xy ."  ▝▀ " 1+
2drop 4 ;
: clb8x8-char-119 ( x y -- w ) \ w
2dup at-xy ."     " 1+
2dup at-xy ." ▐▌▖█" 1+
2dup at-xy ." ▐▌▌█" 1+
2dup at-xy ."  ▀▝▘" 1+
2drop 4 ;
: clb8x8-char-120 ( x y -- w ) \ x
2dup at-xy ."     " 1+
2dup at-xy ." ▝▙▟▘" 1+
2dup at-xy ."  ▟▙ " 1+
2dup at-xy ." ▝▘▝▘" 1+
2drop 4 ;
: clb8x8-char-121 ( x y -- w ) \ y
2dup at-xy ."     " 1+
2dup at-xy ." ▐▌▐▌" 1+
2dup at-xy ." ▝▙▟▌" 1+
2dup at-xy ."  ▄▟▘" 1+
2drop 4 ;
: clb8x8-char-122 ( x y -- w ) \ z
2dup at-xy ."     " 1+
2dup at-xy ." ▝▀█▘" 1+
2dup at-xy ."  ▟▘ " 1+
2dup at-xy ." ▝▀▀▘" 1+
2drop 4 ;
: clb8x8-char-123 ( x y -- w ) \ {
2dup at-xy ."  ▗▛▘" 1+
2dup at-xy ."  ▟▘ " 1+
2dup at-xy ."  ▐▌ " 1+
2dup at-xy ."   ▀▘" 1+
2drop 4 ;
: clb8x8-char-124 ( x y -- w ) \ |
2dup at-xy ."   ▌ " 1+
2dup at-xy ."   ▌ " 1+
2dup at-xy ."   ▌ " 1+
2dup at-xy ."   ▘ " 1+
2drop 4 ;
: clb8x8-char-125 ( x y -- w ) \ }
2dup at-xy ."  ▀▙ " 1+
2dup at-xy ."   ▜▖" 1+
2dup at-xy ."   █ " 1+
2dup at-xy ."  ▀▘ " 1+
2drop 4 ;
: clb8x8-char-126 ( x y -- w ) \ ~
2dup at-xy ." ▗▀▖▐" 1+
2dup at-xy ." ▝ ▝▘" 1+
2dup at-xy ."     " 1+
2dup at-xy ."     " 1+
2drop 4 ;
: clb8x8-char-127 ( x y -- w ) \ 
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-128 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-129 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-130 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-131 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-132 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
: clb8x8-char-133 ( x y -- w ) \ �
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2dup at-xy ." " 1+
2drop 0 ;
create clb8x8-char-table 102 cells allot
 clb8x8-char-table
' clb8x8-char-32 over ! cell+
' clb8x8-char-33 over ! cell+
' clb8x8-char-34 over ! cell+
' clb8x8-char-35 over ! cell+
' clb8x8-char-36 over ! cell+
' clb8x8-char-37 over ! cell+
' clb8x8-char-38 over ! cell+
' clb8x8-char-39 over ! cell+
' clb8x8-char-40 over ! cell+
' clb8x8-char-41 over ! cell+
' clb8x8-char-42 over ! cell+
' clb8x8-char-43 over ! cell+
' clb8x8-char-44 over ! cell+
' clb8x8-char-45 over ! cell+
' clb8x8-char-46 over ! cell+
' clb8x8-char-47 over ! cell+
' clb8x8-char-48 over ! cell+
' clb8x8-char-49 over ! cell+
' clb8x8-char-50 over ! cell+
' clb8x8-char-51 over ! cell+
' clb8x8-char-52 over ! cell+
' clb8x8-char-53 over ! cell+
' clb8x8-char-54 over ! cell+
' clb8x8-char-55 over ! cell+
' clb8x8-char-56 over ! cell+
' clb8x8-char-57 over ! cell+
' clb8x8-char-58 over ! cell+
' clb8x8-char-59 over ! cell+
' clb8x8-char-60 over ! cell+
' clb8x8-char-61 over ! cell+
' clb8x8-char-62 over ! cell+
' clb8x8-char-63 over ! cell+
' clb8x8-char-64 over ! cell+
' clb8x8-char-65 over ! cell+
' clb8x8-char-66 over ! cell+
' clb8x8-char-67 over ! cell+
' clb8x8-char-68 over ! cell+
' clb8x8-char-69 over ! cell+
' clb8x8-char-70 over ! cell+
' clb8x8-char-71 over ! cell+
' clb8x8-char-72 over ! cell+
' clb8x8-char-73 over ! cell+
' clb8x8-char-74 over ! cell+
' clb8x8-char-75 over ! cell+
' clb8x8-char-76 over ! cell+
' clb8x8-char-77 over ! cell+
' clb8x8-char-78 over ! cell+
' clb8x8-char-79 over ! cell+
' clb8x8-char-80 over ! cell+
' clb8x8-char-81 over ! cell+
' clb8x8-char-82 over ! cell+
' clb8x8-char-83 over ! cell+
' clb8x8-char-84 over ! cell+
' clb8x8-char-85 over ! cell+
' clb8x8-char-86 over ! cell+
' clb8x8-char-87 over ! cell+
' clb8x8-char-88 over ! cell+
' clb8x8-char-89 over ! cell+
' clb8x8-char-90 over ! cell+
' clb8x8-char-91 over ! cell+
' clb8x8-char-92 over ! cell+
' clb8x8-char-93 over ! cell+
' clb8x8-char-94 over ! cell+
' clb8x8-char-95 over ! cell+
' clb8x8-char-96 over ! cell+
' clb8x8-char-97 over ! cell+
' clb8x8-char-98 over ! cell+
' clb8x8-char-99 over ! cell+
' clb8x8-char-100 over ! cell+
' clb8x8-char-101 over ! cell+
' clb8x8-char-102 over ! cell+
' clb8x8-char-103 over ! cell+
' clb8x8-char-104 over ! cell+
' clb8x8-char-105 over ! cell+
' clb8x8-char-106 over ! cell+
' clb8x8-char-107 over ! cell+
' clb8x8-char-108 over ! cell+
' clb8x8-char-109 over ! cell+
' clb8x8-char-110 over ! cell+
' clb8x8-char-111 over ! cell+
' clb8x8-char-112 over ! cell+
' clb8x8-char-113 over ! cell+
' clb8x8-char-114 over ! cell+
' clb8x8-char-115 over ! cell+
' clb8x8-char-116 over ! cell+
' clb8x8-char-117 over ! cell+
' clb8x8-char-118 over ! cell+
' clb8x8-char-119 over ! cell+
' clb8x8-char-120 over ! cell+
' clb8x8-char-121 over ! cell+
' clb8x8-char-122 over ! cell+
' clb8x8-char-123 over ! cell+
' clb8x8-char-124 over ! cell+
' clb8x8-char-125 over ! cell+
' clb8x8-char-126 over ! cell+
' clb8x8-char-127 over ! cell+
' clb8x8-char-128 over ! cell+
' clb8x8-char-129 over ! cell+
' clb8x8-char-130 over ! cell+
' clb8x8-char-131 over ! cell+
' clb8x8-char-132 over ! cell+
' clb8x8-char-133 over ! cell+
drop
: clb8x8-char-xy 32 - dup 0>= over 102 < and if cells clb8x8-char-table + @ execute else >r at-xy r> 32 + emit 1 then ;
: clb8x8-string-xy ( x y c-addr u -- ) 
     begin				      
     dup				      
     while				      
     over c@ >r 2over r> clb8x8-char-xy >r        
     2swap swap r> + swap 2swap 1 /string     
     repeat				      
     2drop 2drop			      
     ;
